@@ -4,7 +4,7 @@ use File::Spec;
 use Archive::Tar;
 use File::Path qw( rmtree mkpath );
 use JSON::PP qw( encode_json decode_json );
-use Alien::xz;
+#use Alien::xz;
 use Env qw( @PATH );
 
 my $status_filename = File::Spec->catfile('_alien', '03extract.json');
@@ -18,21 +18,21 @@ my $tar_filename = do {
   $json->{filename};
 };
 
-if($tar_filename =~ /\.xz$/)
-{
-  # This module has a big warning not to use it in
-  # production code.  So.  Yeah don't do that.
-  require Alien::xz;
-  unshift @PATH, Alien::xz->bin_dir;
-
-  my $new = $tar_filename;
-  $new =~ s/\.xz$//;
-
-  system 'xz', '-d', $tar_filename;
-  die "failed to xz" if $?;
-  
-  $tar_filename = $new;
-}
+#if($tar_filename =~ /\.xz$/)
+#{
+#  # This module has a big warning not to use it in
+#  # production code.  So.  Yeah don't do that.
+#  require Alien::xz;
+#  unshift @PATH, Alien::xz->bin_dir;
+#
+#  my $new = $tar_filename;
+#  $new =~ s/\.xz$//;
+#
+#  system 'xz', '-d', $tar_filename;
+#  die "failed to xz" if $?;
+#  
+#  $tar_filename = $new;
+#}
 
 my $tar = Archive::Tar->new;
 $tar->read($tar_filename);
@@ -44,6 +44,18 @@ mkpath $src_dir, 0, 0700;
 print "untar $tar_filename\n";
 chdir($src_dir) || die "unable to chdir $!";
 $tar->extract;
+
+if(-d "pkgconf-1.2.1" && $^O eq 'cygwin')
+{
+  chdir 'pkgconf-1.2.1';
+  require Alien::patch;
+  local $ENV{PATH} = $ENV{PATH};
+  unshift @PATH, Alien::patch->bin_dir;
+  system("@{[ Alien::patch->exe ]} -p1 < ../../../patch/pkgconf-cygwin-1.2.1.diff");
+  die "unable to patch" if $?;
+  chdir '..';
+}
+
 chdir(File::Spec->catdir(File::Spec->updir, File::Spec->updir));
 
 my $filename = do {
